# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class HarmonyClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def ListAgreements(self, request, **kwargs):
        path = "/harmony/agreements"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.harmony.ListAgreementsOutput"),
            **kwargs,
        )

    def GetConsent(self, request, **kwargs):
        path = "/harmony/agreements/"+urllib.parse.quote(request.agreement_id)+"/consent"

        # Cleanup URL parameters to avoid any ambiguity
        request.agreement_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.harmony.GetConsentOutput"),
            **kwargs,
        )

    def SetConsent(self, request, **kwargs):
        path = "/harmony/agreements/"+urllib.parse.quote(request.agreement_id)+"/consent"

        # Cleanup URL parameters to avoid any ambiguity
        request.agreement_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.harmony.SetConsentOutput"),
            **kwargs,
        )

    def FollowShortcut(self, request, **kwargs):
        path = "/harmony/shortcuts/"+urllib.parse.quote(request.shortcut_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.shortcut_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.harmony.FollowShortcutOutput"),
            **kwargs,
        )

