# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/message_endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import message_service_pb2 as eolymp_dot_discussion_dot_message__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/discussion/message_endpoint.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\'eolymp/discussion/message_service.proto2\xf9\x04\n\x0fMessageEndpoint\x12\x9d\x01\n\x0f\x44\x65scribeMessage\x12\'.eolymp.discussion.DescribeMessageInput\x1a(.eolymp.discussion.DescribeMessageOutput\"7\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x02\x12\x00\x12\x97\x01\n\rUpdateMessage\x12%.eolymp.discussion.UpdateMessageInput\x1a&.eolymp.discussion.UpdateMessageOutput\"7\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x02\x1a\x00\x12\x97\x01\n\rDeleteMessage\x12%.eolymp.discussion.DeleteMessageInput\x1a&.eolymp.discussion.DeleteMessageOutput\"7\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x02*\x00\x12\x91\x01\n\x0bVoteMessage\x12#.eolymp.discussion.VoteMessageInput\x1a$.eolymp.discussion.VoteMessageOutput\"7\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x02\"\x00\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.message_endpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _MESSAGEENDPOINT.methods_by_name['DescribeMessage']._options = None
  _MESSAGEENDPOINT.methods_by_name['DescribeMessage']._serialized_options = b'\202\343\n\033\212\343\n\027discussion:message:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\002\022\000'
  _MESSAGEENDPOINT.methods_by_name['UpdateMessage']._options = None
  _MESSAGEENDPOINT.methods_by_name['UpdateMessage']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\002\032\000'
  _MESSAGEENDPOINT.methods_by_name['DeleteMessage']._options = None
  _MESSAGEENDPOINT.methods_by_name['DeleteMessage']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\002*\000'
  _MESSAGEENDPOINT.methods_by_name['VoteMessage']._options = None
  _MESSAGEENDPOINT.methods_by_name['VoteMessage']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\002\"\000'
  _MESSAGEENDPOINT._serialized_start=204
  _MESSAGEENDPOINT._serialized_end=837
# @@protoc_insertion_point(module_scope)
